DESPOTIC
--------

DESPOTIC is a library to Derive the Energetics and SPectra of Optically Thick
Interstellar Clouds. Its capabilities include calculating spectral line
luminosities from clouds of specified physical properties and compositions,
predicting line profiles, calculating rates of heating and cooling due to a
wide range of processes, determining clouds' equilibrium gas and dust
temperatures, and calculating time-dependent thermal evolution of clouds.

DESPOTIC is implemented as a Python package, and is released under the GPL. The
physical model, equations solved, and some tests and example applications are
described in 
[Krumholz (2014)](http://adsabs.harvard.edu/abs/2014MNRAS.437.1662K).


Documentation
=============

Full documentation for DESPOTIC is hosted at [readthedocs](http://despotic.readthedocs.org/).


Downloading DESPOTIC
====================

DESPOTIC is distributed in two ways. The full source distribution, including
example Python programs using it and sample cloud descriptor files, is available from

[bitbucket](https://bitbucket.org/krumholz/despotic/)

and can be obtained via git by doing

`git clone git@bitbucket.org:krumholz/despotic.git`

Despotic is also available through the [python package index](https://pypi.python.org/pypi/DESPOTIC). If you have pip installed, you can just type

`pip install despotic`

The tarball may also be downloaded from PyPi and installed using the
standard Python distutils method.